==> okta-sdk-api-19.0.1-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/ErrorPage.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.ContentSecurityPolicySetting;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * ErrorPage
 */
@JsonPropertyOrder({ ErrorPage.JSON_PROPERTY_PAGE_CONTENT, ErrorPage.JSON_PROPERTY_CONTENT_SECURITY_POLICY_SETTING })
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class ErrorPage implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_PAGE_CONTENT = "pageContent";
    private String pageContent;

    public static final String JSON_PROPERTY_CONTENT_SECURITY_POLICY_SETTING = "contentSecurityPolicySetting";
    private ContentSecurityPolicySetting contentSecurityPolicySetting;

    public ErrorPage() {
    }

    public ErrorPage pageContent(String pageContent) {

        this.pageContent = pageContent;
        return this;
    }

    /**
     * The HTML for the page
     *
     * @return pageContent
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "The HTML for the page")
    @JsonProperty(JSON_PROPERTY_PAGE_CONTENT)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getPageContent() {
        return pageContent;
    }

    @JsonProperty(JSON_PROPERTY_PAGE_CONTENT)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setPageContent(String pageContent) {
        this.pageContent = pageContent;
    }

    public ErrorPage contentSecurityPolicySetting(ContentSecurityPolicySetting contentSecurityPolicySetting) {

        this.contentSecurityPolicySetting = contentSecurityPolicySetting;
        return this;
    }

    /**
     * Get contentSecurityPolicySetting
     *
     * @return contentSecurityPolicySetting
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_CONTENT_SECURITY_POLICY_SETTING)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public ContentSecurityPolicySetting getContentSecurityPolicySetting() {
        return contentSecurityPolicySetting;
    }

    @JsonProperty(JSON_PROPERTY_CONTENT_SECURITY_POLICY_SETTING)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setContentSecurityPolicySetting(ContentSecurityPolicySetting contentSecurityPolicySetting) {
        this.contentSecurityPolicySetting = contentSecurityPolicySetting;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        ErrorPage errorPage = (ErrorPage) o;
        return Objects.equals(this.pageContent, errorPage.pageContent)
                && Objects.equals(this.contentSecurityPolicySetting, errorPage.contentSecurityPolicySetting);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(pageContent, contentSecurityPolicySetting);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class ErrorPage {\n");
        sb.append("    pageContent: ").append(toIndentedString(pageContent)).append("\n");
        sb.append("    contentSecurityPolicySetting: ").append(toIndentedString(contentSecurityPolicySetting))
                .append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-20.0.1-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/ErrorPage.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.ContentSecurityPolicySetting;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * ErrorPage
 */
@JsonPropertyOrder({ ErrorPage.JSON_PROPERTY_PAGE_CONTENT, ErrorPage.JSON_PROPERTY_CONTENT_SECURITY_POLICY_SETTING })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-01-23T09:50:29.349096-06:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class ErrorPage implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_PAGE_CONTENT = "pageContent";
    private String pageContent;

    public static final String JSON_PROPERTY_CONTENT_SECURITY_POLICY_SETTING = "contentSecurityPolicySetting";
    private ContentSecurityPolicySetting contentSecurityPolicySetting;

    public ErrorPage() {
    }

    public ErrorPage pageContent(String pageContent) {

        this.pageContent = pageContent;
        return this;
    }

    /**
     * The HTML for the page
     *
     * @return pageContent
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "The HTML for the page")
    @JsonProperty(JSON_PROPERTY_PAGE_CONTENT)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getPageContent() {
        return pageContent;
    }

    @JsonProperty(JSON_PROPERTY_PAGE_CONTENT)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setPageContent(String pageContent) {
        this.pageContent = pageContent;
    }

    public ErrorPage contentSecurityPolicySetting(ContentSecurityPolicySetting contentSecurityPolicySetting) {

        this.contentSecurityPolicySetting = contentSecurityPolicySetting;
        return this;
    }

    /**
     * Get contentSecurityPolicySetting
     *
     * @return contentSecurityPolicySetting
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_CONTENT_SECURITY_POLICY_SETTING)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public ContentSecurityPolicySetting getContentSecurityPolicySetting() {
        return contentSecurityPolicySetting;
    }

    @JsonProperty(JSON_PROPERTY_CONTENT_SECURITY_POLICY_SETTING)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setContentSecurityPolicySetting(ContentSecurityPolicySetting contentSecurityPolicySetting) {
        this.contentSecurityPolicySetting = contentSecurityPolicySetting;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        ErrorPage errorPage = (ErrorPage) o;
        return Objects.equals(this.pageContent, errorPage.pageContent)
                && Objects.equals(this.contentSecurityPolicySetting, errorPage.contentSecurityPolicySetting);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(pageContent, contentSecurityPolicySetting);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class ErrorPage {\n");
        sb.append("    pageContent: ").append(toIndentedString(pageContent)).append("\n");
        sb.append("    contentSecurityPolicySetting: ").append(toIndentedString(contentSecurityPolicySetting))
                .append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
